@@ -79,7 +79,7 @@ void HWSpi::SetSpdr(unsigned char val) {
 } 
 
 void HWSpi::SetSpsr(unsigned char val) { 
-    if (trace_on) {
+    if (core->trace_on) {
         traceOut << "spsr is read onyl! ";
     } else {
         cerr << "spsr is read only! ";
@@ -397,29 +397,12 @@ unsigned char HWSpi::GetSpsr() {
 
 unsigned char HWSpi::GetSpcr() { return spcr; }
 
-#if 0
-bool HWSpi::IsIrqFlagSet(unsigned int vector) {
-    return 1;
-
-    /* this function mjust be removed later
-    if (vector== vectorForSpif) {
-
-        return (( spcr & SPIE ) && ( spsr & SPIF) );
-    } else {
-        cout << "WWWWAAAARRRNNNNIIIINNNNGGG  Warning there is HWSPI called to get a irq vector which is not assigned for!?!?!?!?";
-    }
-    return 0;
-    */
-
-}
-#endif
-
 void HWSpi::ClearIrqFlag(unsigned int vector) {
     if (vector== vectorForSpif) {
         spsr&=0xff-SPIF;
         irqSystem->ClearIrqFlag( vectorForSpif);
     } else {
-        cout << "WWWWAAAARRRNNNNIIIINNNNGGG  Warning there is HWSPI called to get a irq vector which is not assigned for!?!?!?!?";
+        cerr << "WWWWAAAARRRNNNNIIIINNNNGGG  Warning there is HWSPI called to get a irq vector which is not assigned for!?!?!?!?";
     }
 }
 
@@ -511,9 +494,9 @@ void HWMegaSpi::SetSpsr(unsigned char val) {
 
 } 
 
-unsigned char RWSpdr::operator=(unsigned char val) { trioaccess("Spdr",val);spi->SetSpdr(val);  return val; } 
-unsigned char RWSpsr::operator=(unsigned char val) { trioaccess("Spsr",val);spi->SetSpsr(val);  return val; } 
-unsigned char RWSpcr::operator=(unsigned char val) { trioaccess("Spcr",val);spi->SetSpcr(val);  return val; } 
+unsigned char RWSpdr::operator=(unsigned char val) { if (core->trace_on) trioaccess("Spdr",val);spi->SetSpdr(val);  return val; } 
+unsigned char RWSpsr::operator=(unsigned char val) { if (core->trace_on) trioaccess("Spsr",val);spi->SetSpsr(val);  return val; } 
+unsigned char RWSpcr::operator=(unsigned char val) { if (core->trace_on) trioaccess("Spcr",val);spi->SetSpcr(val);  return val; } 
 
 RWSpdr::operator unsigned char() const { return spi->GetSpdr(); } 
 RWSpsr::operator unsigned char() const { return spi->GetSpsr(); }
