@@ -61,7 +61,11 @@ void HWUart::SetUdr(unsigned char val) {
     udrWrite=val;
     if ( usr&UDRE) { //the data register was empty
         usr &=0xff-UDRE; //so we are not able to send another value now 
+        if (ucr & UDRIE) { // UDRE irq was allready set, so clear it
+            irqSystem->ClearIrqFlag(vectorUdre);
+        }
     }
+
 } 
 
 
@@ -178,9 +182,13 @@ unsigned int HWUart::CpuCycleRx() {
     //
     //this part MUST! ONLY BE CALLED IF THE PRESCALER OUTPUT COUNTS
     if ( ucr & RXEN) {
+        // will be used to cause interrupts (in the end of this if)
+        unsigned char usr_old=usr;
+
         switch (rxState) {
             case RX_WAIT_FOR_HIGH: //wait for startbit
                 if (pinRx==1) rxState=RX_WAIT_FOR_LOWEDGE;
+                
                 break;
 
             case RX_WAIT_FOR_LOWEDGE:
@@ -289,7 +297,10 @@ unsigned int HWUart::CpuCycleRx() {
                     }
                 }
 
-                if (cntRxSamples>15) {
+                if (
+                        (ucsrc&USBS) && (cntRxSamples>16) || //if 2 stopbits used we have to wait full bit frame
+                        (!(ucsrc&USBS)) && (cntRxSamples>10) //in case of only 1 stopbit we can shorten the stopbit
+                   ) {
 
                     if ( rxLowCnt<rxHighCnt) { //the bit was high this is ok
                         udrRead=rxDataTmp&0xff;
@@ -311,11 +322,14 @@ unsigned int HWUart::CpuCycleRx() {
                         rxHighCnt=0;
                         rxState= RX_READ_STOPBIT2;  
                     } else {
-                        if (usr|RXC) { //RXC is allready set->Overrun Error
+                        if (usr&RXC) { //RXC is allready set->Overrun Error
                             usr|=OR;
                         }
                         usr|=RXC; //receiving is complete, regardless of framing error!
-                        rxState= RX_WAIT_FOR_HIGH;
+                        if (rxLowCnt<rxHighCnt)
+                            rxState = RX_WAIT_FOR_LOWEDGE;
+                        else 
+                            rxState = RX_WAIT_FOR_HIGH;
                     }
                 }	
                 break;
@@ -331,7 +345,7 @@ unsigned int HWUart::CpuCycleRx() {
                         }
                     }
 
-                    if (cntRxSamples>15) {
+                    if (cntRxSamples>10) { //the last stopbit could allways be shorter than normal data-bit
                         if ( rxLowCnt<rxHighCnt) { //the bit was high this is ok
                             usr&=0xff-FE;
                         }
@@ -340,7 +354,10 @@ unsigned int HWUart::CpuCycleRx() {
                     }
 
                     usr|=RXC; //receiving is complete, regardless of framing error!
-                    rxState= RX_WAIT_FOR_HIGH;
+                    if (rxLowCnt<rxHighCnt)
+                        rxState = RX_WAIT_FOR_LOWEDGE;
+                    else 
+                        rxState = RX_WAIT_FOR_HIGH;
                 }	
 
 
@@ -349,6 +366,19 @@ unsigned int HWUart::CpuCycleRx() {
             case RX_DISABLED:
                 break;
         } //end of switch
+
+        // check if as a result of this operation any interrupt flags sholud be changed.
+        unsigned char irqold= ucr&usr_old;
+        unsigned char irqnew= ucr&usr;
+  	 
+  	 
+        unsigned char changed=irqold^irqnew;
+        unsigned char setnew= changed&irqnew;
+        unsigned char clearnew= changed& (~irqnew);
+  	 
+        CheckForNewSetIrq(setnew);
+        CheckForNewClearIrq(clearnew);
+  	
     } // end of rx enabled
     return 0;
 }
@@ -356,15 +386,19 @@ unsigned int HWUart::CpuCycleRx() {
 
 unsigned int HWUart::CpuCycleTx() {
     /*************************************** TRANCEIVER PART **********************************/
-    unsigned char usr_old=usr;
+    //unsigned char usr_old=usr;
 
     baudCnt16++;
     if (baudCnt16==16) { //1 time baud rate - baud rate / 16 here
         baudCnt16=0;
 
         if (ucr & TXEN ) {	//transmitter enabled
+
+            // will be used to cause interrupts int the end of this if
+            unsigned char usr_old=usr;
+
             if (!(usr & UDRE) ) { // there is new data in udr
-                if ((usr & TXC)| (txState==TX_FIRST_RUN)) { //transmitter is empty
+                if ((usr & TXC)| (txState==TX_FIRST_RUN)|txState==TX_FINISH) { //transmitter is empty
                     //shift data from udr->transmit shift register
                     txDataTmp=udrWrite;
                     if (ucr & TXB8) { // there is a 1 in txb8
@@ -430,9 +464,9 @@ unsigned int HWUart::CpuCycleTx() {
                             txState=TX_SEND_STARTBIT;
                         } // end of new data in udr
                         else 
-                        { 
-                            txState=TX_AFTER_STOPBIT;
-                        }
+                            { 
+                                txState=TX_AFTER_STOPBIT;
+                            }
                     }
                     break;
 
@@ -450,57 +484,52 @@ unsigned int HWUart::CpuCycleTx() {
                         txState=TX_SEND_STARTBIT;
                     } // end of new data in udr
                     else 
-                    { 
-                        txState=TX_AFTER_STOPBIT;
-                    }
+                        { 
+                            txState=TX_AFTER_STOPBIT;
+                        }
                     break;
 
                 case TX_AFTER_STOPBIT: //transmit complete and no new data
-                    //leave state untouched
                     usr|=TXC; 			//set the txc 
+                    txState=TX_FINISH; 
                     break;
 
 
 
                 case TX_DISABLED:
                 case TX_FIRST_RUN:
+                case TX_FINISH:
                     break;
 
             } //end of switch tx state
+
+            // check if some interrupts should be caused as a result
+            // of this sending tact
+            unsigned char irqold= ucr&usr_old;
+            unsigned char irqnew= ucr&usr;
+
+
+            unsigned char changed=irqold^irqnew;
+            unsigned char setnew= changed&irqnew;
+            unsigned char clearnew= changed& (~irqnew);
+
+            CheckForNewSetIrq(setnew);
+            CheckForNewClearIrq(clearnew);
+
         } // end of tx enabled 
     }	//end of 1 time baudrate
 
-    unsigned char irqold= ucr&usr_old;
-    unsigned char irqnew= ucr&usr;
-
-
-    unsigned char changed=irqold^irqnew;
-    unsigned char setnew= changed&irqnew;
-    unsigned char clearnew= changed& (~irqnew);
-
-    CheckForNewSetIrq(setnew);
-    CheckForNewClearIrq(clearnew);
-
 
     return 0;
 }
 
 HWUart::HWUart( AvrDevice *core, HWIrqSystem *s, PinAtPort tx, PinAtPort rx, unsigned int vrx, unsigned int vudre, unsigned int vtx):
-Hardware(core), irqSystem(s), pinTx(tx), pinRx(rx), vectorRx(vrx), vectorUdre(vudre), vectorTx(vtx) {
-    core->AddToCycleList(this);
-    //irqSystem->RegisterIrqPartner(this, vectorRx);
-    //irqSystem->RegisterIrqPartner(this, vectorUdre);
-    //irqSystem->RegisterIrqPartner(this, vectorTx);
-
-    Reset();
-}
+    Hardware(core), irqSystem(s), pinTx(tx), pinRx(rx), vectorRx(vrx), vectorUdre(vudre), vectorTx(vtx) {
+        core->AddToCycleList(this);
+        Reset();
+    }
 
 HWUsart::HWUsart( AvrDevice *core, HWIrqSystem *s, PinAtPort tx, PinAtPort rx, PinAtPort xck, unsigned int vrx, unsigned int vudre, unsigned int vtx): HWUart( core, s, tx, rx, vrx, vudre, vtx), pinXck(xck) {
-    core->AddToCycleList(this);
-    //irqSystem->RegisterIrqPartner(this, vectorRx);
-    //irqSystem->RegisterIrqPartner(this, vectorUdre);
-    //irqSystem->RegisterIrqPartner(this, vectorTx);
-
     Reset();
 }
 
@@ -518,10 +547,16 @@ void HWUart::Reset() {
     SetFrameLengthFromRegister(); 
 }
 
-unsigned char HWUart::GetUdr() { 
-    usr&=0xff-RXC; // unset RXC register
+unsigned char HWUart::GetUdr() {
+    if (usr&RXC) {
+        usr&=0xff-RXC; // unset RXC register
+        if (ucr & RXC) {
+            irqSystem->ClearIrqFlag(vectorRx); // and clear interrupt flag
+        }	 
+    }
     return udrRead;
 }
+
 unsigned char HWUart::GetUsr() { return usr; }
 unsigned char HWUart::GetUcr() { return ucr; }
 unsigned char HWUart::GetUbrr() { return ubrr&0xff; }
@@ -551,11 +586,11 @@ void HWUart::CheckForNewClearIrq(unsigned char val) {
 }
 
 
-unsigned char RWUdr::operator=(unsigned char val) { trioaccess("Udr",val);uart->SetUdr(val);  return val; } 
-unsigned char RWUsr::operator=(unsigned char val) { trioaccess("Usr",val);uart->SetUsr(val);  return val; } 
-unsigned char RWUcr::operator=(unsigned char val) { trioaccess("Ucr",val);uart->SetUcr(val);  return val; } 
-unsigned char RWUbrr::operator=(unsigned char val) { trioaccess("Ubrr",val);uart->SetUbrr(val); return val; } 
-unsigned char RWUbrrhi::operator=(unsigned char val) { trioaccess("Ubrrhi",val);uart->SetUbrrhi(val); return val; } 
+unsigned char RWUdr::operator=(unsigned char val) { if (core->trace_on) trioaccess("Udr",val);uart->SetUdr(val);  return val; } 
+unsigned char RWUsr::operator=(unsigned char val) { if (core->trace_on) trioaccess("Usr",val);uart->SetUsr(val);  return val; } 
+unsigned char RWUcr::operator=(unsigned char val) { if (core->trace_on) trioaccess("Ucr",val);uart->SetUcr(val);  return val; } 
+unsigned char RWUbrr::operator=(unsigned char val) { if (core->trace_on) trioaccess("Ubrr",val);uart->SetUbrr(val); return val; } 
+unsigned char RWUbrrhi::operator=(unsigned char val) { if (core->trace_on) trioaccess("Ubrrhi",val);uart->SetUbrrhi(val); return val; } 
 
 
 RWUdr::operator unsigned char() const { return uart->GetUdr(); } 
@@ -564,9 +599,9 @@ RWUcr::operator unsigned char() const { return uart->GetUcr(); }
 RWUbrr::operator unsigned char() const { return uart->GetUbrr(); } 
 RWUbrrhi::operator unsigned char() const { return uart->GetUbrrhi(); } 
 
-unsigned char RWUcsra::operator=(unsigned char val) { trioaccess("Ucsra",val);uart->SetUsr(val);  return val; }
-unsigned char RWUcsrb::operator=(unsigned char val) { trioaccess("Ucsrb",val);uart->SetUcr(val);  return val; }
-unsigned char RWUcsrc::operator=(unsigned char val) { trioaccess("Ucsrc",val);uart->SetUcsrc(val);  return val; }
+unsigned char RWUcsra::operator=(unsigned char val) { if (core->trace_on) trioaccess("Ucsra",val);uart->SetUsr(val);  return val; }
+unsigned char RWUcsrb::operator=(unsigned char val) { if (core->trace_on) trioaccess("Ucsrb",val);uart->SetUcr(val);  return val; }
+unsigned char RWUcsrc::operator=(unsigned char val) { if (core->trace_on) trioaccess("Ucsrc",val);uart->SetUcsrc(val);  return val; }
 
 RWUcsra::operator unsigned char() const { return uart->GetUsr(); } 
 RWUcsrb::operator unsigned char() const { return uart->GetUcr(); } 
