@@ -4,7 +4,8 @@
 using namespace std;
 
 extern ofstream traceOut;
-extern int trace_on;
+extern int global_trace_on;
+extern int global_verbose_on;
 void trioaccess(const char *t, unsigned char val);
 
 void StartTrace(const char *fname);
